#
# spec file for package translate-toolkit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%bcond_with doc
%endif 
%if "%{flavor}" == "man+doc"
%define psuffix -man
%bcond_with test
%bcond_without doc
%endif
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
%bcond_with doc
%endif
%define modname translate_toolkit
%define pkgname translate-toolkit
%bcond_without libalternatives

%define binaries_and_manpages %{shrink:\
    pretranslate poclean pocompile poconflicts podebug pofilter pogrep pomerge porestructure posegment poswap poterminology \
    android2po csv2po csv2tbx dtd2po flatxml2po html2po ical2po idml2po ini2po json2po \
    moz2po mozfunny2prop mozlang2po odf2xliff oo2po oo2xliff php2po phppo2pypo \
    po2csv po2dtd po2flatxml po2html po2ical po2idml po2ini po2json po2moz po2mozlang po2oo \
    po2php po2prop po2rc po2resx po2sub po2symb po2tiki po2tmx po2ts po2txt po2web2py \
    po2wordfast po2xliff po2yaml pot2po prop2po pypo2phppo rc2po resx2po sub2po symb2po \
    tbx2po tiki2po ts2po txt2po web2py2po xliff2odf xliff2oo xliff2po yaml2po}
%define binaries %{shrink: %binaries_and_manpages\
    pocommentclean pocompendium pocount pomigrate2 popuretext poreencode posplit prop2mozfunny \
    build_tmdb pydiff tmserver junitmsgfmt md2po po2md}
%define manpages translatetoolkit %binaries_and_manpages

Name:           translate-toolkit%{psuffix}
Version:        3.15.5
Release:        1.1
Summary:        Tools and API to assist with translation and software localization
License:        GPL-2.0-or-later
URL:            https://toolkit.translatehouse.org/
Source:         https://files.pythonhosted.org/packages/source/t/%{modname}/%{modname}-%{version}.tar.gz
Patch0:         xliff-xsd-no-network.patch
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module cheroot >= 9}
BuildRequires:  %{python_module cwcwidth >= 0.1.10}
BuildRequires:  %{python_module iniparse >= 0.5}
BuildRequires:  %{python_module lxml >= 5.2.0}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module phply >= 1.2.5}
BuildRequires:  %{python_module ruamel.yaml >= 0.17.21}
BuildRequires:  %{python_module setuptools >= 42}
BuildRequires:  %{python_module setuptools_scm >= 6.2}
BuildRequires:  %{python_module vobject >= 0.9.6.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gettext-runtime
BuildRequires:  git-core
BuildRequires:  iso-codes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       gettext-runtime
Requires:       python
Requires:       python-cwcwidth >= 0.1.10
Requires:       python-lxml >= 5.2.0
# The following are for the full experience of translate-toolkit
Recommends:     %{name}-doc
Recommends:     %{name}-man
Recommends:     gaupol
Recommends:     iso-codes
Recommends:     python-Levenshtein >= 0.12
Recommends:     python-aeidon >= 1.13
Recommends:     python-beautifulsoup4 >= 4.3
Recommends:     python-charset-normalizer >= 3.3.2
Recommends:     python-cheroot >= 10
Recommends:     python-iniparse >= 0.5
Recommends:     python-mistletoe >= 1.2.1
Recommends:     python-phply >= 1.2.6
Recommends:     python-pyenchant >= 3.2.2
Recommends:     python-pyparsing >= 3.1.1
Recommends:     python-ruamel.yaml >= 0.18.5
Recommends:     python-vobject >= 0.9.6.1
%if %{without test} && %{without doc} && ("%{python_flavor}" == "python3" || "%{?python_provides}" == "python3")
Provides:       translate-toolkit = %{version}-%{release}
Obsoletes:      translate-toolkit < %{version}-%{release}
%endif
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Levenshtein >= 0.12}
BuildRequires:  %{python_module aeidon >= 1.13}
BuildRequires:  %{python_module beautifulsoup4 >= 4.3}
BuildRequires:  %{python_module charset-normalizer >= 3.3.2}
BuildRequires:  %{python_module mistletoe >= 1.2.1}
BuildRequires:  %{python_module pyenchant >= 3.2.2}
BuildRequires:  %{python_module pyparsing >= 3.1.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module translate-toolkit = %{version}}
BuildRequires:  %{python_module xml}
BuildRequires:  %{python_module syrupy}
BuildRequires:  gaupol
%endif
%if %{with doc}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module furo}
BuildRequires:  %{python_module sphinxcontrib-copybutton}
BuildRequires:  %{python_module sphinxext-opengraph}
BuildRequires:  %{python_module translate-toolkit = %{version}}
Requires:       %{pkgname} = %{version}
Supplements:    %{pkgname} = %{version}
%endif
%python_subpackages

%if "%{flavor}" == "man+doc"
%description
The %{pkgname}-man package contains manual pages for %{pkgname}.

%package -n %{pkgname}-doc
Summary:        Tools and API to assist with translation and software localization -- HTML docs
Requires:       %{pkgname} = %{version}
BuildArch:      noarch

%description -n %{pkgname}-doc
The %{pkgname}-doc package contains Translate Toolkit documentation in HTML format.

%package -n %{pkgname}-devel-doc
Summary:        Tools and API to assist with translation and software localization -- API docs
Requires:       %{pkgname} = %{version}
Requires:       %{pkgname}-doc = %{version}
Provides:       %{pkgname}-devel = %{version}
Obsoletes:      %{pkgname}-devel < %{version}
BuildArch:      noarch

%description -n %{pkgname}-devel-doc
The %{pkgname}-devel-doc package contains Translate Toolkit API documentation for developers wishing to build new tools for the
toolkit or to use the libraries in other localization tools.

%else

%description
The Translate Toolkit is a set of software and documentation designed to help
make the lives of localizers both more productive and less frustrating.

The software includes programs to convert localization formats to the common
PO, and emerging XLIFF format.  There are also programs to check and manage PO
and XLIFF files.  Online documentation includes guides on using the tools,
running a localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling various
localization storage formats: DTD, properties, OpenOffice.org GSI/SDF,
CSV, MO, Qt .ts, TMX, TBX, WordFast txt, Gettext .mo, Windows RC, and
of course PO and XLIFF.  It also provides scripts to convert between
these formats.

Also part of the Toolkit are Python programs to create word counts, merge
translations and perform various checks on translation files.
%endif

%prep
%setup -q -n %{modname}-%{version}
%autopatch -p1

#Fix for shebang errors:
for lib in translate/{*.py,*/*.py,*/*/*.py}; do
 sed -i '\|%{_bindir}/env |d' $lib
done

find . -name jquery.js -exec dos2unix '{}' \;

%build
%if !%{with test}
%if !%{with doc}
%pyproject_wheel

%else

# build docs
pushd docs
# Can't use parallel build here!
%make_build SPHINXBUILD=sphinx-build -j1 man html
#no hidden files
find _build -name '.?*' -delete
popd
%endif
%endif

%install
%if !%{with test}
%if !%{with doc}
%pyproject_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Prepare alternatives for binaries
for binary in %{binaries} ; do
%python_clone -a %{buildroot}%{_bindir}/$binary
done

%else

# create manpages
mkdir -p %{buildroot}%{_mandir}/man1
for program in %{binaries}; do
    MPAGE="%{buildroot}%{_mandir}/man1/$program.1"
    LC_ALL=C PYTHONPATH=. %{_bindir}/$program --manpage > "$MPAGE" || rm -f "$MPAGE"
done
install -m 644 docs/_build/man/* %{buildroot}%{_mandir}/man1/

# move documentation files to datadir, use default flavor version for common
install -d -m 755 %{buildroot}%{_defaultdocdir}/%{modname}
mv docs/_build/html %{buildroot}%{_defaultdocdir}/%{modname}
%{python_expand rm -rf %{buildroot}%{$python_sitelib}/translate/docs
rm -rf %{buildroot}home/abuild/.local/lib/python%{$python_version}/site-packages/
}

# create symlinks for man pages
%fdupes -s %{buildroot}%{_mandir}

# Prepare alternatives for manpages
for mpage in %{manpages} ; do
%python_clone -a %{buildroot}%{_mandir}/man1/$mpage.1
done

%endif
%endif

%check
%if %{with test}
rm -v tests/translate/storage/test_fluent.py
%pytest
%endif

%if !%{with test}
%if !%{with doc}

%pre
%python_libalternatives_reset_alternative pretranslate

%files %{python_files}
%license COPYING
%doc README.rst
%{lua: for b in string.gmatch(rpm.expand("%binaries"),"%S+") do print(rpm.expand("%python_alternative %{_bindir}/" .. b) .. "\n") end}
%{python_sitelib}/translate
%{python_sitelib}/translate_toolkit-%{version}.dist-info

%else

%pre
%python_libalternatives_reset_alternative translatetoolkit.1%{?ext_man}

%files %{python_files}
%license COPYING
%doc README.rst
%{lua: for m in string.gmatch(rpm.expand("%manpages"),"%S+") do print(rpm.expand("%python_alternative %{_mandir}/man1/" .. m .. ".1") .. "\n") end}
# needed because we are building manpages separately
%if %{with libalternatives}
%{lua: for m in string.gmatch(rpm.expand("%manpages"),"%S+") do print(rpm.expand("%dir %{_datadir}/libalternatives/" .. m .. "") .. "\n") end}
%{lua: for m in string.gmatch(rpm.expand("%manpages"),"%S+") do print(rpm.expand("%{_datadir}/libalternatives/" .. m .. "/*%{python_version_nodots}.conf") .. "\n") end}
%endif

%files -n %{pkgname}-doc
%dir %{_defaultdocdir}/%{modname}
%doc %{_defaultdocdir}/%{modname}/html/
%exclude %{_defaultdocdir}/%{modname}/html/api
%exclude %{_defaultdocdir}/%{modname}/html/_sources

%files -n %{pkgname}-devel-doc
%doc %{_defaultdocdir}/%{modname}/html/api
%doc %{_defaultdocdir}/%{modname}/html/_sources
%endif
%endif

%changelog
* Thu Jun 19 2025 Markéta Machová <mmachova@suse.com>
- Fix the doc build
* Wed Jun 18 2025 Markéta Machová <mmachova@suse.com>
- Update to 3.15.5
  * Improvements to multiple formats.
  * Packaging now follows PEP 621.
  * Documentation improvements and cleanups.
  * Added support for Compose Multiplatform Resources
  * Added language definition for Toki Pona
- Convert to libalternatives
* Wed Jan 15 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Only provide the 'translate-toolkit' symbol in the actual
  packages, not the doc/test flavored ones.
* Fri Jan 10 2025 Markéta Machová <mmachova@suse.com>
- Split the documentation from the main package to avoid many new
  dependencies in Ring1
  * man pages are being made optional by this change
* Mon Jan  6 2025 Markéta Machová <mmachova@suse.com>
- Update to 3.14.5
  * Improvements to multiple formats.
  * Dropped support for Python 3.8.
  * Improved multistring implementation.
  * Python 3.13 compatiblity.
- Drop merged py313.patch
* Wed Oct 30 2024 Markéta Machová <mmachova@suse.com>
- Update to 3.13.3
  * Improved handling of MO files
- Drop merged sphinx-intersphinx.patch
- Add py313.patch
* Thu Jul  4 2024 Markéta Machová <mmachova@suse.com>
- Update to 3.13.1
  * Added support for FormatJS
  * Several improvements to the PO, XML and Properties formats.
  * Updated language definitions to include CLDR aliases.
  * Dropped unmatained Mozilla l10n scripts.
- Drop merged 0001-tests-Adjust-to-changed-aeidon-behavior.patch
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 3.13.1:
  * Compatibility with current pytest and setuptools.
  * Updated language definitions to include CLDR aliases.
  * Dropped unmatained Mozilla l10n scripts.
  * Updated aeidon compatibility
  * PO: Fixed newlines handling in notes
  * PO: Improved header handling
  * PO: Avoid adding duplicate context when merging duplicates
- drop 0001-tests-Adjust-to-changed-aeidon-behavior.patch:
  (upstream)
* Mon Apr  8 2024 Ana Guerrero <ana.guerrero@suse.com>
- Add patch 0001-tests-Adjust-to-changed-aeidon-behavior.patch for
  the new the "in-between" newline logic
* Sun Jan 14 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.12.1
  * Fixed parsing of some Android translation files
- Release 3.12.0
  * Improved Android format compatibility with plurals and CDATA
  * Added support for MOKO resources
  * Gettext PO honors line wrapping configuration when adding unit
  * Use correct plurals matching Qt implementation
  * Properties notes behave consistently with other formats
  * RESX/RESW use Windows newlines instead of UNIX ones
  * INI does not treat lines starting with rem as comments
  * Improved JSON round-tri
- Release 3.11.1
  * Updated language definitions to CLDR 44
- Release 3.11.0
  * Improved Android format compatibility
  * Improved JSON round-trip
  * Add support for relative locations in TS2
  * Python 3.12 is now supported
  * Tests are no longer distributed in the module
  * Switched to ruff for linting and formatting
- Release 3.10.1
  * Added android2po converter
  * Improved support of the RC and XLIFF formats
- Release 3.10.0
  * Added support for Markdown
  * Improved support of the XLIFF and Fluent formats
* Sat Jul  1 2023 Markéta Machová <mmachova@suse.com>
- Update to 3.9.2
  * Fluent: Attributes are now exposed as translatable entities
  * Fluent: Terms are now prefixed with -
  * POXLIFF: Avoid using "None" as translation for untranslated pluralized units
  * TBX: Improved notes parsing
  * improved CSV output of pocount and refactored it
  * junitmsgfmt has been rewritten in Python
  * po2csv, csv2po: Add support for preserving context
  * dropped support for Python 3.7
  * TS2: Fixed handling of files without a source string
* Fri Mar 17 2023 Luiz Fernando Ranghetti <elchevive@opensuse.org>
- update to 3.8.6
  * Improved support for go-i18n v2
  * Fixed parsing unicode RC files with pragma encoding
  * Add support for go-i18n v2
  * Fixes in the i18next v4 and GWT formats
  * Fixes in the JSON, YAML and stringsdict formats
  * Adds support for gotext and i18next v4 JSON variants
- switch back to upstream tarball
- fix for boo#1208870 (translate/share folder not packaged)
* Mon Jan  2 2023 Ben Greiner <code@bnavigator.de>
- update to 3.8.0
  * JSON: Fixed serialization for some corner case keys
  * PO: Wrapping is now compatible with GNU gettext 0.21.1
  * Fluent: Consolidate error handling to be similar as with other
    formats
  * Fluent: Add support for extracting placeables
  * LISA (XLIFF, Android, ...): Allow to customize behavior of
    empty XML tags
  * RC: Added support for MENUEX block and DISCARDABLE attribute
- Move to PEP517 build
- Add pyparsing as build requirment for manpage genaration: It is
  not pulled in automatically anymore (python-packaging 22)
- Fix alternatives uninstall command: Master ends in 1.gz
  (%%ext_man)
* Wed Oct 26 2022 Dirk Müller <dmueller@suse.com>
- update to 3.7.3:
  * Addded new classified rewriter
  * Updated CLDR data
  * Fixes in the Android, GWT and RC formats.
  * Rewritten installation to use modern setuptools features.
  * Added support for Resource Dictionary format.
  * Fixes in the CSV, PO and RC formats.
  * Fixes in the JSON, YAML, RC, and properties formats.
  * see https://docs.translatehouse.org/projects/translate-toolkit/en/latest/releases/3.7.3.html
  * see https://docs.translatehouse.org/projects/translate-toolkit/en/latest/releases/3.7.2.html
  * see https://docs.translatehouse.org/projects/translate-toolkit/en/latest/releases/3.7.1.html
  * see https://docs.translatehouse.org/projects/translate-toolkit/en/latest/releases/3.7.0.html
  * see https://docs.translatehouse.org/projects/translate-toolkit/en/latest/releases/3.6.2.html
- switch to obs_scm due to broken upstream tarball (gh#translate/translate#4744)
* Tue Oct  4 2022 Martin Liška <mliska@suse.cz>
- Drop not needed BuildRequires: subversion.
* Fri Apr 29 2022 Markéta Machová <mmachova@suse.com>
- Update to 3.6.1
  * Dropped support for Python 3.6
  * Added support for Python 3.10
  * Switch to charset-normalizer from chardet for more reliable detection
* Tue Feb  1 2022 Luiz Fernando Ranghetti <elchevive@opensuse.org>
- update to 3.5.3:
  * Fixed updating files with DOS end of lines in PO format
  * Improved error reporting for parse errors in PO format
  * Fixed adding strings to empty Ruby YAML file
  * Better handling of multiline stringtable translations in po2rc
  * Update CLDR data to 37.0.0
* Thu Dec  2 2021 Dirk Müller <dmueller@suse.com>
- skip fluent from testing, we don't depend on it anyway (it is optional)
* Mon Nov 29 2021 Dirk Müller <dmueller@suse.com>
- update to 3.5.1:
  * Added support for stringsdict and Fluent formats
  * Minor fixes in JSON and PO formats
  * Bug fixes in RC, Fluent and HTML formats
  * Improvements in the XLIFF and RC formats
  * Fixes in the RC format
* Mon May  3 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.3.6
  * fixed handling of plurals in GWT properties
  * lxml requirement was raised to 4.6.3 to address CVE-2021-28957
  * Consistent using of XML entity for non-breakable space
  * Fix newlines round-trip
* Wed Mar 17 2021 Luiz Fernando Ranghetti <elchevive@opensuse.org>
- Add back python and python-setuptools Requires and update some recommended
  dependecies versions
* Mon Mar 15 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.3.3
  * add some new tools
  * poterminology: Fix regex escaping
  * wordfast: Fix header processing
  * misc: Add support for Python 3.9
- Drop merged versioned_executables.patch
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Only the primary Python 3 flavor shall provide unflavored
  capability translate-toolkit. gh#openSUSE/python-rpm-macros#66
* Sun Dec  6 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 3.2.0
  * Fixed bugs in YAML, Android and JSON formats
  * Dropped support for Python 3.5
- refresh versionend_executables.patch
- Fix name definition of -devel-doc package because of stricter
  python-rpm-macros %%python_subpackages requirement
- move html docs in common file tree to -doc package in order to
  avoid conflicts for multiple python flavor packages
  gh#openSUSE/python-rpm-macros#66
- replace my_install_alternatives by python_install_alternative
  * fix manpages alternatives install
* Fri Oct 16 2020 Matthias Fehring <buschmann23@opensuse.org>
- Update to 3.1.1:
  * Fixed comparing units
  * Fixed removal of units from a storage
- Update to 3.1.0:
  * Improved round trip for JSON and YAML formats.
  * Fixes for multiple formats (Android, JSON, CSV, Windows RC).
  * Added support for XWiki formats.
* Tue Jun 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.0:
  * Fixes for multiple formats (PO, XLIFF, JSON, Properties, HTML, PHP, Windows RC).
  * Dropped support for Python 2.7.
  * Removed lot of deprecated code.
- Drop merged patch test-mo-endian.patch
* Wed Jun 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- We need full python interpreter bsc#1172650, boo#1195269
* Wed May 13 2020 Matej Cepl <mcepl@suse.com>
- Clean up, rewrite to single-spec style, and use %%pytest macro.
- We have to install, but remove afterwards, when in the test phase.
- Add versioned_executables.patch to use partially installed
  versioned executables.
* Fri May  1 2020 Matej Cepl <mcepl@suse.com>
- Swtich to multibuild to separate tests
* Wed Mar 18 2020 Andreas Schwab <schwab@linux-m68k.org>
- test-mo-endian.patch: tell msgfmt to use correct endianness
* Tue Mar  3 2020 Ondřej Súkup <mimi.vx@gmail.com>
- temporary disable TestYAMLResourceStore.test_empty_key because
  ruamel.yaml has different behaviour on empty keys from version
    0.16.6
* Wed Jan 22 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.0:
  * Fixes to work with new weblate
* Thu Jul 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.0:
  * Added new Flat XML format and converters.
  * Fixes for multiple formats.
- Remove merged patches:
  * pycountry.patch
  * test-pytest310.patch
* Thu Apr  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not depend on strace, it is not really needed
* Fri Mar 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with current pycountry:
  * pycountry.patch
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop not needed lxml-doc dependency
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid mixing historic and modern option syntax for tar.
- Replace find -exec rm by just find -delete.
* Mon Jan 28 2019 Luiz Fernando Ranghetti <elchevive@opensuse.org>
- Correct the Source URL
* Thu Jan 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Make sure the documentation is generated properly
- Enable testsuite
- Add patches from debian for tests to pass:
  * sphinx-intersphinx.patch
  * test-pytest310.patch
  * xliff-xsd-no-network.patch
* Tue Dec 18 2018 sbrabec@suse.com
- Update to 2.3.1:
  * But fixes.
  * INI: Enabled support for Python3 provided.
  * Use backports.csv module on Python 2 to align the behavior
    with Python 3 and drop many hacks.
  * Removed deprecated getoutput, add new depreceations.
  * Code cleanup; many converterters refactored.
* Wed Mar 21 2018 elchevive@opensuse.org
- update to 2.3.0
  * Full rewrite of the PHP format greatly extending the support.
  * Added YAML format converters.
  * Major refactor of converters code.
- drop patch translate-toolkit-2.0.0-python-six.diff not needed
  on Leap 15.0
* Tue Dec 26 2017 astieger@suse.com
- update to 2.2.5:
  * Fixed bug when adding new units to XLIFF store.
  * Added support for i18next JSON dialect.
  * Improved WebExtension JSON dialect support.
* Tue Nov 14 2017 jmatejek@suse.com
- drop unneeded requirement for python-utidy
- drop unneeded requirements for diff_match_patch
- switch to python3
* Mon Aug 28 2017 elchevive@opensuse.org
- Update do 2.2.4
  * Added support for nested and WebExtension JSON dialects.
  * po2txt no longer converts non-translatable strings.
  * Improvement for puncspace check.
  * Support for .xliff extension.
* Mon Jun 26 2017 elchevive@opensuse.org
- Update do 2.2.3
  * Added MinimalChecker and ReducedChecker checkers.
  * Fixed resolving of country names translations.
  * Refactored functions for resolving language/country names translation to be memory efficient.
  * Improvements for ts and subtitles formats.
  * Added –preserveplaceholders argument to podebug.
  * Fixed Montenegrin language name.
* Fri Jun 16 2017 elchevive@opensuse.org
- add python-pycountry as Requires
- Update do 2.2.0
  * Avoid resolving external entities while parsing XML.
  * Improvements for Android, ts and resx formats.
  * Added support for PHP nested arrays.
  * Added Kabyle language
* Mon Mar 20 2017 elchevive@opensuse.org
- Update do 2.1.0
  * Fixed RomanianChecker checks.
  * Added an iOS checker style.
  * Changed plural equations for Slovenian, Persian, Kazakh and Kyrgyz.
  * Several fixes in formats and tools.
* Mon Mar  6 2017 lnussel@suse.de
- lower python-six requirement to 1.9 again to make translate-toolkit work on
  Leap. There is no real requirement on 1.10:
  https://github.com/translate/translate/pull/3488
  * translate-toolkit-2.0.0-python-six.diff
* Sun Feb 26 2017 dimstar@opensuse.org
- Explicitly package %%{_defaultdocdir}/%%{name}/html: fix build with
  RPM 4.13.
* Mon Jan 30 2017 elchevive@opensuse.org
- Update do 2.0.0
  * po2txt works correctly again when --threshold option is passed
  (https://github.com/translate/translate/issues/3499) boo#999286
* Tue Jan 24 2017 elchevive@opensuse.org
- Add missing Requires: python-setuptools
* Mon Jan 16 2017 elchevive@opensuse.org
- Update to 1.99.9 (2.0.0 RC2)
  * Minor fixes
* Thu Sep  1 2016 elchevive@opensuse.org
- Update to 1.99.5 (2.0.0 Beta 5)
  * Minor fixes
- require lxml 3.5.0 or newer
* Wed Jul 27 2016 buschmann23@opensuse.org
- Update to 1.99.3 (2.0.0 Beta 3)
  * Python 3 compatibility thanks to Claude Paroz
  * Dropped support for Python 2.6
  * Changes in storage API to expose a more standardized API
- require python 2.7 or newer
* Thu Apr 28 2016 michal@cihar.com
- Update to 1.14.0-rc1
* Tue Nov 10 2015 mcihar@suse.cz
- Fix documentation build (breaks in parallel build)
* Tue Nov 10 2015 mcihar@suse.cz
- python-six is required for build as well (for API docs)
* Tue Nov 10 2015 mcihar@suse.cz
- Remove Sphinx build cache before building docs
* Wed Jul 29 2015 dimstar@opensuse.org
- Require python-six: translate/misc/quote.py depends on it.
* Wed Jul 15 2015 mcihar@suse.cz
- use spec-cleaner to sort dependencies
* Wed Jul 15 2015 mcihar@suse.cz
- make dependency on several optional features only recommended: vobject,
  Levenshtein, aeidon, iniparse
- remove not needed xapian build dependency
- remove not used simplejson from build/runtime dependencies
* Fri May 15 2015 elchevive@opensuse.org
- updated to version 1.13.0
- updated Source URL and run spec-cleaner
  Major changes
  New converters for IDML format
  Support for new .Net Resource (.resx) format
  Extensive cleanup on ODF converters
  New quality checks
    Some bugfixes and improvements
* Thu Nov  6 2014 mcihar@suse.cz
- remove not needed gaupol build dependency
* Tue Aug 12 2014 elchevive@opensuse.org
- updated to version 1.12.0
  Major changes
  Properties and DTD formats fix a number of issues
  Massive code cleanup looking forward Python 3 compatibility
  Important changes in development process to ease testing
* Thu Jan 30 2014 elchevive@opensuse.org
- updated to version 1.11.0
  Major changes:
  The PO format now matches Gettext more closely
  PHP format adds a number of new features
  Support for Python 2.5 has been dropped
* Sun Jul 14 2013 elchevive@opensuse.org
- add 2 missing BuildRequires (python-Levenshtein and change
  python-aeidon with gaupol)
* Fri Jun 28 2013 elchevive@opensuse.org
- Add python-{Levenshtein,aeidon} as Requires and remove again
  diff_match_patch as its not allowed on Factory (license issue)
* Tue Mar 26 2013 fa0sck@gmail.com
- New upstream version (1.10.0)
  * devel package renamed as devel-doc.
* Sat Jan 12 2013 dmitry.rojkov@gmail.com
- initial repackaging
* Tue Jun  5 2012 i@marguerite.su
- fix sles builds.
  * version tag for buildarch: noarch.
* Thu May 10 2012 elchevive@opensuse.org
- Remove psyco references as it is a dead project
* Thu Apr 19 2012 elchevive@opensuse.org
- Add Provides: python-translate-toolkit for compatibility with old packages
* Mon Mar 26 2012 elchevive@opensuse.org
- Cosmetic change in 'for' used to remove shebangs
* Tue Mar 20 2012 elchevive@opensuse.org
- Add proper specfile header as requested in sr#109322
* Wed Mar 14 2012 elchevive@opensuse.org
- Fix for bnc#750652 (remove Apache-2.0 file as the programa has a fallbak)
* Sun Feb 26 2012 elchevive@opensuse.org
- Add ifelse to python-pyenchant (new name for > 12.1)
* Wed Feb 22 2012 elchevive@opensuse.org
- Fix the non-executable-script warning
* Wed Apr 13 2011 elchevive@opensuse.org
- Updated to version 1.9.0
  Highlighted improvements
  - Faster terminology matching
  - Several small optimisations to performance and memory use
  - More advanced state support (visible in pocount and Virtaal 0.7)
  - Improved language detection models (+South African languages)
  - Improve handling of printf variable reordering [Jacques Beaurain]
  - Review of the wording of the messages of pofilter checks
  - Better sentence segmentation for some non-Latin languages
  - More supported formats for podebug
  - Extra options for pomerge, pogrep and po2oo/xliff2oo. The new pogrep options made this possible for GNOME: http://translate.org.za/blogs/friedel/en/content/better-lies-about-gnome-localisation
  Most relevant for Pootle:
  - Support for Xapian 1.2 (bug 1766) [Rimas Kudelis]
  - Work around some changes introduced in Django 1.2.5/1.3
  Format support:
  - Always use UNIX line endings for PO (even on Windows)
  - XLIFF and .ts files now shows "fuzzy" only the target present
  - Improved support for .ts comment as context (bug 1739)
  - Support for Java properties in UTF-8 encoding
  - More natural string ordering in json converter
  - Improved handling of trailing spaces in Mozilla DTD files
  - Removed unused support for _old_ KDE plurals in pocount
  ...and several small bugfixes
* Mon Dec 27 2010 elchevive@opensuse.org
- Removed 11.1 references and python- prefix
* Fri Nov 19 2010 elchevive@opensuse.org
- Updated to version 1.8.1
* Tue Aug 17 2010 elchevive@opensuse.org
- Updated to version 1.8.0
- Set Gaupol as Suggestion
* Wed May 12 2010 elchevive@opensuse.org
- Updated to version 1.7.0
* Fri Mar  5 2010 elchevive@opensuse.org
- Updated to version 1.6.0
- Added python-enchant as Requires
* Tue Feb 23 2010 elchevive@opensuse.org
- Rename -doc to -devel (as it is devel's docs)
- Added more requires (for ical2po, sub2po work)
- Remove duplicated docs in -devel
* Mon Feb 22 2010 elchevive@opensuse.org
- Package split (-doc) and manpages created (using Fedora's .spec)
* Tue Feb 16 2010 elchevive@opensuse.org
- Package updated to version 1.5.3
* Mon Jan 25 2010 elchevive@opensuse.org
- Added gettext-runtime as requirement
* Wed Jan 20 2010 elchevive@opensuse.org
- Added python-lxml as requirement
* Thu Jan 14 2010 elchevive@opensuse.org
- Initial release 1.5.2 - spec/rpmlint copyed from thomas-schaite repository
